@@ -48,8 +48,8 @@ class TestElementGroup(unittest.TestCase):
         r1 = rects[1]
         self.assertEqual(r1.implicit_x, 0)
         self.assertEqual(r1.implicit_y, 0)
-        self.assertEqual(r1.implicit_width, 200)
-        self.assertEqual(r1.implicit_height, 200)
+        self.assertAlmostEqual(r1.implicit_width, 200)
+        self.assertAlmostEqual(r1.implicit_height, 200)
         print(r1.bbox())
 
     def test_issue_107(self):
@@ -68,4 +68,4 @@ class TestElementGroup(unittest.TestCase):
         m *= "translate(100,100)"  # Test __imul__
         n = m * 'scale(2)'  # Test __mult__
         self.assertEqual(n[0][0].transform, Matrix("matrix(2,0,0,2,200,200)"))
-        self.assertEqual(m[0][0].transform, Matrix("matrix(1,0,0,1,100,100)"))
\ No newline at end of file
+        self.assertEqual(m[0][0].transform, Matrix("matrix(1,0,0,1,100,100)"))
